@@ -196,7 +196,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 traslados = self.dom.createElement('cfdi:Traslados')
                 total_traslados = 0
                 for traslado in self.impuestos_trasladados:
-                    total_traslados += float(traslado.get('importe'))
+                    total_traslados += float(traslado.get('importe', 0))
                     traslados.appendChild(self.get_traslados(traslado))
                 impuestos.appendChild(traslados)
                 impuestos.setAttribute('TotalImpuestosTrasladados', str(total_traslados))
@@ -204,7 +204,7 @@ class GeneratorXmlFourDotZero(AbstractGeneratorXml):
                 retenciones = self.dom.createElement('cfdi:Retenciones')
                 total_retenciones = 0
                 for retencion in self.impuestos_retenidos:
-                    total_retenciones += float(retencion.get('importe'))
+                    total_retenciones += float(retencion.get('importe', 0))
                     retenciones.appendChild(self.get_retenciones(retencion))
                 impuestos.appendChild(retenciones)
                 impuestos.setAttribute('TotalImpuestosRetenidos', str(total_retenciones))
